<?php
/**
 * This file is part of
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * pragmaMx is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Revision: 1.8 $
 * $Author: tora60 $
 * $Date: 2014-03-20 14:36:06 $
 *
 * based on: probe.php from http://www.a51dev.com
 */

define("STATUS_OK", "ok");
define("STATUS_WARNING", "warning");
define("STATUS_ERROR", "error");
// define("THIS_FILE", basename(__FILE__));

/* min. Voraussetzungen definieren */
// gut: http://www.oxid-esales.com/de/produkte/facts/oxid-eshop-community-edition/systemvoraussetzungen.html
$minvalues = array(/* minimale Versionen und Werte */
    'mysql' => MX_SETUP_MIN_MYSQLVERSION,
    'php' => MX_SETUP_MIN_PHPVERSION,
    'memlimit' => '33554432', // in byte = 32MB
    );

/**
 * TestResult
 *
 * @package
 * @author tora60
 * @copyright Copyright (c) 2013
 * @version $Id: functions_check.php,v 1.8 2014-03-20 14:36:06 tora60 Exp $
 * @access public
 */
class TestResult {
    var $message;
    var $status;
    var $class;

    function __construct($message, $status = STATUS_OK)
    {
        $this->message = $message;
        $this->status = $status;
        // switch ($status) {
        // case STATUS_ERROR:
        // $this->class = 'btn-danger';
        // break;
        // case STATUS_WARNING:
        // $this->class = 'btn-warning';
        // break;
        // case STATUS_OK:
        // default:
        // $this->class = 'btn-success';
        // }
    }
}

/**
 * show_test_results()
 *
 * @param mixed $results
 * @return
 */
function show_test_results($results)
{
    ob_start();

    ?>
    <div class="row">
        <ul>
            <?php foreach($results as $result) {
                echo '<li class="' . $result->status . '"><span>' . $result->status . '</span> - ' . $result->message . '</li>';
            }?>
        </ul>
        <div id="legend">
            <h3><?php echo _LEGEND ?></h3>
            <ul>
                <li class="ok"><?php echo _LEGEND_OK ?></li>
                <li class="warning"><?php echo _LEGEND_WARN ?></li>
                <li class="error"><?php echo _LEGEND_ERR ?></li>
            </ul>
        </div>
    </div>
  <?php
    return ob_get_clean();
}

/**
 * check_db()
 *
 * @param mixed $dbresults
 * @return
 */
function check_db(&$dbresults)
{
    // Funktion wird hier nicht benötigt!!
    return null;

    global $minvalues;

    if (!(DB_HOST && DB_NAME)) {
        return null;
    }

    $dbresults = array();

    if ($connection = @mysql_connect(DB_HOST, DB_USER, DB_PASS)) {
        $dbresults[] = new TestResult(_DBTEST_CONNECT, STATUS_OK);

        if (mysql_select_db(DB_NAME, $connection)) {
            $dbresults[] = new TestResult(_DBTEST_SELECTED, STATUS_OK);

            $mysql_version = mysql_get_server_info($connection);

            if (version_compare($mysql_version, $minvalues['mysql']) >= 0) {
                $dbresults[] = new TestResult(sprintf(_DBTEST_VERSION, $mysql_version), STATUS_OK);
            } else {
                $dbresults[] = new TestResult(sprintf(_DBTEST_VERSIONOLD, $mysql_version), STATUS_ERROR);
                return false;
            }
        } else {
            $dbresults[] = new TestResult(sprintf(_DBTEST_SELECTFAIL, mysql_error()), STATUS_ERROR);
            return false;
        }
    } else {
        $dbresults[] = new TestResult(sprintf(_DBTEST_CONNECTFAIL, mysql_error()), STATUS_ERROR);
        return false;
    }

    return true;
}

/**
 * Validate PHP platform
 *
 * @param array $result
 */
function validate_php(&$results)
{
    global $minvalues;
    if (version_compare(PHP_VERSION, $minvalues['php']) == -1) {
        $results[] = new TestResult(sprintf(_ENVTEST_PHPFAIL, $minvalues['php'], PHP_VERSION), STATUS_ERROR);
        return false;
    } else {
        $results[] = new TestResult(sprintf(_ENVTEST_PHPOK, PHP_VERSION), STATUS_OK);
        return true;
    }
}

/**
 * Validate memory limit
 *
 * @param array $result
 */
function validate_memory_limit(&$results)
{
    global $minvalues;

    $memory_limit = php_config_value_to_bytes(ini_get('memory_limit'));

    $formatted_memory_limit = $memory_limit === -1 ? 'unlimited' : format_file_size($memory_limit);

    if ($memory_limit === -1 || $memory_limit >= $minvalues['memlimit']) {
        $results[] = new TestResult(sprintf(_ENVTEST_MEMOK, $formatted_memory_limit), STATUS_OK);
        return true;
    } else {
        $results[] = new TestResult(sprintf(_ENVTEST_MEMFAIL, format_file_size($minvalues['memlimit']), $formatted_memory_limit), STATUS_ERROR);
        return false;
    }
}

/**
 * Validate PHP extensions
 *
 * @param array $results
 */
function validate_extensions(&$results)
{
    $ok = true;

    $required_extensions = array(/* benötigte */
        'mysql',
        'pcre',
        'session',
        'mbstring', // => _EXTTEST_MB,
        'gd', // => _EXTTEST_GD,
        'iconv', // => _EXTTEST_ICONV,
        'json',
        );

    $recommended_extensions = array(/* empfohlene */
        // 'gd' => _EXTTEST_GD,
        // 'mbstring' => _EXTTEST_MB,
        // 'imap' => _EXTTEST_IMAP,
        'xml' => _EXTTEST_XML,
        'curl' => _EXTTEST_CURL,
        'tidy' => _EXTTEST_TIDY,
        'pdo' => _EXTTEST_PDO,
        'zip' => _EXTTEST_ZIP,
        );

    foreach($required_extensions as $required_extension) {
        if (extension_loaded($required_extension)) {
            $results[] = new TestResult(sprintf(_EXTTEST_REQFOUND, $required_extension), STATUS_OK);
        } else {
            $results[] = new TestResult(sprintf(_EXTTEST_REQFAIL, $required_extension), STATUS_ERROR);
            $ok = false;
        }
    }

    foreach($recommended_extensions as $recommended_extension => $recommended_extension_desc) {
        if (extension_loaded($recommended_extension)) {
            $results[] = new TestResult(sprintf(_EXTTEST_RECFOUND, $recommended_extension), STATUS_OK);
        } else {
            $results[] = new TestResult(sprintf(_EXTTEST_RECNOTFOUND, $recommended_extension, $recommended_extension_desc), STATUS_WARNING);
        }
    }
    return $ok;
}

/**
 * Validate available PDO drivers
 *
 * @param array $result
 */
function validate_pdo(&$results)
{
    if (!extension_loaded('pdo')) {
        $results[] = new TestResult(sprintf(_EXTTEST_REQFAIL, 'pdo'), STATUS_ERROR);
        return false;
    }

    $usable_drivers = array('mysql');
    $drivers = PDO::getAvailableDrivers();
    $available_drivers = array_intersect($drivers, $usable_drivers);

    if (!$available_drivers) {
        $drivers = implode(',', $usable_drivers);
        $results[] = new TestResult(sprintf(_PDOTEST_FAIL, $drivers), STATUS_ERROR);
        return false;
    }

    foreach ($available_drivers as $driver) {
        $results[] = new TestResult(sprintf(_PDOTEST_OK, $driver), STATUS_OK);
    }
    return true;
}

/**
 * Convert filesize value from php.ini to bytes
 *
 * Convert PHP config value (2M, 8M, 200K...) to bytes. This function was taken from PHP documentation. $val is string
 * value that need to be converted
 *
 * @param string $val
 * @return integer
 */
function php_config_value_to_bytes($val)
{
    $val = trim($val);
    $last = strtolower($val{strlen($val)-1});
    switch ($last) {
        // The 'G' modifier is available since PHP 5.1.0
        case 'g':
            $val *= 1024;
        case 'm':
            $val *= 1024;
        case 'k':
            $val *= 1024;
    }
    return (integer) $val;
}

/**
 * Format filesize
 *
 * @param string $value
 * @return string
 */
function format_file_size($value)
{
    $data = array('TB' => 1099511627776,
        'GB' => 1073741824,
        'MB' => 1048576,
        'kb' => 1024,
        );

    $value = (integer) $value;
    foreach($data as $unit => $bytes) {
        $in_unit = $value / $bytes;
        if ($in_unit > 0.9) {
            return trim(trim(number_format($in_unit, 2), '0'), '.') . $unit;
        }
    }
    return $value . 'b';
}

/**
 * check_type_support()
 * Check version of GDLib
 *
 * @return
 */
function check_type_support()
{
    // GDlib installiert?
    if (!function_exists('gd_info')) {
        return false;
    }
    $gd_info = gd_info();
    if (!is_array($gd_info) || !isset($gd_info['GD Version'])) {
        return false;
    }
    $gd_info['GD_Version'] = @preg_replace('#[^0-9.]#', '', $gd_info['GD Version']);
    return $gd_info;
}

?>